# testarsenal

This is a library to make both unit ('unit') tests and functional testing of
django applications easier.

It has a class to supplement the Django TestCase, with checks for url
resolution, view redirects, etc.

It also has a class to make selenium browser tests easier.
